@@ -618,24 +618,53 @@ describe('vim.lsp.completion: item conversion', function()
             },
           },
         },
+        {
+          label = 'insert_replace_edit',
+          kind = 9,
+          textEdit = {
+            newText = 'foobar',
+            insert = {
+              start = { line = 0, character = 7 },
+              ['end'] = { line = 0, character = 11 },
+            },
+            replace = {
+              start = { line = 0, character = 0 },
+              ['end'] = { line = 0, character = 0 },
+            },
+          },
+        },
       },
     }
     local expected = {
-      abbr = ' this_thread',
-      dup = 1,
-      empty = 1,
-      icase = 1,
-      info = '',
-      kind = 'Module',
-      menu = '',
-      abbr_hlgroup = '',
-      word = 'this_thread',
+      {
+        abbr = ' this_thread',
+        dup = 1,
+        empty = 1,
+        icase = 1,
+        info = '',
+        kind = 'Module',
+        menu = '',
+        abbr_hlgroup = '',
+        word = 'this_thread',
+      },
+      {
+        abbr = 'insert_replace_edit',
+        dup = 1,
+        empty = 1,
+        icase = 1,
+        info = '',
+        kind = 'Module',
+        menu = '',
+        abbr_hlgroup = '',
+        word = 'foobar',
+      },
     }
     local result = complete('  std::this|', completion_list)
     eq(7, result.server_start_boundary)
-    local item = result.items[1]
-    item.user_data = nil
-    eq(expected, item)
+    for _, item in ipairs(result.items) do
+      item.user_data = nil
+    end
+    eq(expected, result.items)
   end)
 
   it('should search from start boundary to cursor position', function()
@@ -834,8 +863,6 @@ describe('vim.lsp.completion: protocol', function()
     end)
   end)
 
-  after_each(clear)
-
   local function assert_matches(fn)
     retry(nil, nil, function()
       fn(exec_lua('return _G.capture.matches'))
@@ -1008,6 +1035,34 @@ describe('vim.lsp.completion: protocol', function()
     end)
   end)
 
+  it('treats 2-triggers-at-once as "last char wins"', function()
+    local results1 = {
+      isIncomplete = false,
+      items = {
+        {
+          label = 'first',
+        },
+      },
+    }
+    create_server('dummy1', results1, { trigger_chars = { '-' } })
+    local results2 = {
+      isIncomplete = false,
+      items = {
+        {
+          label = 'second',
+        },
+      },
+    }
+    create_server('dummy2', results2, { trigger_chars = { '>' } })
+
+    feed('i->')
+
+    assert_matches(function(matches)
+      eq(1, #matches)
+      eq('second', matches[1].word)
+    end)
+  end)
+
   it('executes commands', function()
     local completion_list = {
       isIncomplete = false,
@@ -1205,8 +1260,6 @@ describe('vim.lsp.completion: integration', function()
     end)
   end)
 
-  after_each(clear)
-
   it('puts cursor at the end of completed word', function()
     local completion_list = {
       isIncomplete = false,
